==> PDE_1.0.0.tar.gz: PDE/inst/doc/PDE.R <==
## ---- out.width = "50%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_empty_mac.png")

## ---- out.width = "50%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_linux.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.choose_variables_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.input_output_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.parameters_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.docus_empty.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.open_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.display_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.browse_and_mark_empty.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.input_output_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.parameters_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.docus_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.start_MTX_example.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_Open_analysis_file.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_load_tsv.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_load_pdfs.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_open_pdf.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_jump_to.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_table-sentence.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_show_txtcontent_only.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_show_original_text.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_browse.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX.png")

==> PDE_1.3.0.tar.gz: PDE/inst/doc/PDE.R <==
## ---- out.width = "50%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_empty_linux.png")

## ---- out.width = "50%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_mac.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.choose_variables_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.search_words_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.filter_words_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.parameters_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.docus_empty.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.open_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.display_empty.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface.browse_and_mark_empty.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.parameters_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.docus_MTX_example.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_analyzer_user_interface.start_MTX_example.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_empty_win.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_Open_analysis_file.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_load_tsv.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_load_pdfs.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_open_pdf.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_jump_to.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_table-sentence.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_show_txtcontent_only.png")

## ---- out.width = "75%", fig.align = "center", echo = FALSE-------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_show_original_text.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX_browse.png")

## ---- out.width = "100%", fig.align = "center", echo = FALSE------------------
knitr::include_graphics("scrnshots/Screenshot_PDE_reader_user_interface_MTX.png")
